// Export the main client
export { SmartRequestClient } from './smartrequestclient.js';

// Export types
export type { HttpMethod, ResponseType, FormField, RetryConfig, TimeoutConfig } from './types/common.js';
export { 
  PaginationStrategy,
  type TPaginationConfig as PaginationConfig,
  type OffsetPaginationConfig,
  type CursorPaginationConfig,
  type LinkPaginationConfig,
  type CustomPaginationConfig,
  type TPaginatedResponse as PaginatedResponse
} from './types/pagination.js';

// Convenience factory functions
import { SmartRequestClient } from './smartrequestclient.js';

/**
 * Create a client pre-configured for JSON requests
 */
export function createJsonClient<T = any>() {
  return SmartRequestClient.create<T>();
}

/**
 * Create a client pre-configured for form data requests
 */
export function createFormClient<T = any>() {
  return SmartRequestClient.create<T>();
}

/**
 * Create a client pre-configured for binary data
 */
export function createBinaryClient<T = any>() {
  return SmartRequestClient.create<T>().responseType('binary');
}

/**
 * Create a client pre-configured for streaming
 */
export function createStreamClient() {
  return SmartRequestClient.create().responseType('stream');
}